pub struct InstructDataset { /* private fields */ }Expand description
Instruction-tuning dataset (multi-turn conversations).
Implementations
Sourceimpl InstructDataset
impl InstructDataset
Sourcepub fn new(examples: Vec<TrainingExample>) -> Self
pub fn new(examples: Vec<TrainingExample>) -> Self
Create a new instruct dataset from a vector of examples.
Sourcepub fn from_examples(
examples: impl IntoIterator<Item = TrainingExample>,
) -> Self
pub fn from_examples( examples: impl IntoIterator<Item = TrainingExample>, ) -> Self
Create a new instruct dataset from an iterator of examples.
Sourcepub fn push(&mut self, example: TrainingExample)
pub fn push(&mut self, example: TrainingExample)
Append a single example to the dataset.
Sourcepub fn extend(&mut self, examples: impl IntoIterator<Item = TrainingExample>)
pub fn extend(&mut self, examples: impl IntoIterator<Item = TrainingExample>)
Extend the dataset with an iterator of examples.
Sourcepub fn remove(&mut self, index: usize) -> DatasetResult<TrainingExample>
pub fn remove(&mut self, index: usize) -> DatasetResult<TrainingExample>
Remove and return the example at the given index.
Sourcepub fn total_estimated_tokens(&self) -> usize
pub fn total_estimated_tokens(&self) -> usize
Total estimated tokens across all examples.
Sourcepub fn as_slice(&self) -> &[TrainingExample]
pub fn as_slice(&self) -> &[TrainingExample]
Get all examples as a slice.
Sourcepub fn into_inner(self) -> Vec<TrainingExample>
pub fn into_inner(self) -> Vec<TrainingExample>
Consume self and return the underlying Vec.