pub struct TrainingMessage {
pub role: TrainingRole,
pub content: String,
pub tool_calls: Option<Vec<Value>>,
pub tool_call_id: Option<String>,
pub name: Option<String>,
}Expand description
A single message in a training conversation.
Fields
role: TrainingRoleRole of the message sender.
content: StringText content of the message.
tool_calls: Option<Vec<Value>>Optional tool calls made by the assistant.
tool_call_id: Option<String>ID of the tool call this message responds to.
name: Option<String>Optional name of the sender.
Implementations
Sourceimpl TrainingMessage
impl TrainingMessage
Sourcepub fn new(role: TrainingRole, content: impl Into<String>) -> Self
pub fn new(role: TrainingRole, content: impl Into<String>) -> Self
Create a new training message with the given role and content.
Sourcepub fn tool(content: impl Into<String>, tool_call_id: impl Into<String>) -> Self
pub fn tool(content: impl Into<String>, tool_call_id: impl Into<String>) -> Self
Create a tool response message.
Sourcepub fn estimated_tokens(&self) -> usize
pub fn estimated_tokens(&self) -> usize
Estimated token count (rough: ~4 chars per token).